@@ -163,6 +163,11 @@ def write_json(path, data, indent=4):
         json.dump(data, fp, indent=indent)
 
 
+def write_temp_json(data, indent=4):
+    with open('./temp.json', 'w') as fp:
+        json.dump(data, fp, indent=indent)
+
+
 def read_json(path):
     with open(path, 'r') as fp:
         users = json.load(fp)
@@ -176,7 +181,7 @@ def read_file(path):
 
 
 def write_file(path, data):
-    with open(path, 'w') as fp:
+    with open(path, 'w', encoding="utf-8") as fp:
         fp.write(data)
 
 
