@@ -16,6 +16,7 @@ from undetected_chromedriver.v2 import Chrome, ChromeOptions
 from .local_storage import LocalStorage
 from .relative_path import relative_path
 import shutil
+import pydash
 
 
 class DriverUtils():
@@ -40,20 +41,28 @@ class DriverUtils():
     def get_element_by_id(self, selector, wait=None):
         return get_element_by_id(self, selector, wait)
 
-    def is_in_page(self, page, wait=None):
+    def is_in_page(self, target, wait=None, raiseException=False):
+        
+        def check_page(driver, target):
+            if isinstance(target, str):
+                return target in driver.current_url
+            else: 
+                return pydash.some(target, lambda x: x in driver.current_url)
+        
         if wait is None:
-            return page in self.current_url
+            return check_page(self, target)
         else:
             time = 0
             while time < wait:
-                print(self.current_url)
-                if page in self.current_url:
+                if check_page(self, target):
                     return True
 
                 sleep_time = 0.2
                 time += sleep_time
                 sleep(sleep_time)
-
+                
+        if raiseException:
+            raise Exception(f"Page {target} not found")
         return False
 
     def get_element_text(self, element):
@@ -208,6 +217,7 @@ RANDOM = "RANDOM"
 
 def add_essential_options(options, user_id, window_size, user_agent):
     options.add_argument("--start-maximized")
+    
     if window_size is not None:
         if window_size == RANDOM:
             window_size = WindowSizesInstance.get_unique_random_value()
@@ -248,6 +258,8 @@ GOOGLE_DRIVER = 'google_driver'
 
 
 def hide_automation_flags(options):
+    options.add_argument('--disable-blink-features=AutomationControlled')
+
     options.add_experimental_option(
         "excludeSwitches", ["enable-automation"])
     options.add_experimental_option('useAutomationExtension', False)
@@ -295,11 +307,17 @@ def create_driver_by_driver_type(driver_type, user_id, window_size, user_agent,
         else:
             desired_capabilities = None
         print("Creating Driver")
+        hide_automation_flags(options)
         if is_undetected:
             driver = MyChrome(desired_capabilities=desired_capabilities,
                               options=options, version_main=108)
         else:
-            hide_automation_flags(options)
+
+            
+            # CAPTCHA
+            options.arguments.extend(
+                ["--disable-web-security", "--disable-site-isolation-trials", "--disable-application-cache"])
+
             path = relative_path("drivers/chromedriver.exe", 1)
             driver = MyGoogleChrome(
                 desired_capabilities=desired_capabilities,
